==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnMovingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDetailDescription } from "./WebColumnMovingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEventArgsDetailDescriptionMetadata.c(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebColumnMovingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnMovingEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebColumnMovingEventArgsDetail", () => new WebColumnMovingEventArgsDetailDescription());
            a.z("WebColumnMovingEventArgsDetail", WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEventArgsDetailDescriptionMetadata, 'WebColumnMovingEventArgsDetailDescriptionMetadata');
    WebColumnMovingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnMovingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDetailDescription } from "./WebColumnMovingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEventArgsDetailDescriptionMetadata.c(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnMovingEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebColumnMovingEventArgsDetail", () => new WebColumnMovingEventArgsDetailDescription());
            a.ab("WebColumnMovingEventArgsDetail", WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEventArgsDetailDescriptionMetadata, 'WebColumnMovingEventArgsDetailDescriptionMetadata');
    WebColumnMovingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDetailDescriptionMetadata;
})();
